# ComicWalkerDownloader aka cowado

CLI tool to download manga from ComicWalker.

## Installation

```bash
pip install cowado
```

Or from source:

```bash
git clone https://github.com/Timolio/ComicWalkerDownloader.git
cd ComicWalkerDownloader
pip install .
```

## Usage

Navigate to the folder where you want the images to be saved, then run:

```bash
cowado [comicwalker_url]
```

Example:

```bash
cowado https://comic-walker.com/detail/KC_006351_S/episodes/KC_0063510000500011_E?episodeType=latest
```

## Notes

Make sure you do not use this tool to infringe any copyright laws.
